! -*- fortran -*-
! WARNING! THIS IS A GENERATED FILE!!
! ANY EDITS YOU PUT HERE WILL BE LOST!
! ==> Instead, edit topdir/ompi/include/mpif-values.pl.

! Copyright (c) 2004-2006 The Trustees of Indiana University and Indiana
!                         University Research and Technology
!                         Corporation.  All rights reserved.
! Copyright (c) 2004-2010 The University of Tennessee and The University
!                         of Tennessee Research Foundation.  All rights
!                         reserved.
! Copyright (c) 2004-2007 High Performance Computing Center Stuttgart,
!                         University of Stuttgart.  All rights reserved.
! Copyright (c) 2004-2005 The Regents of the University of California.
!                         All rights reserved.
! Copyright (c) 2006-2012 Cisco Systems, Inc.  All rights reserved.
! Copyright (c) 2009      Oak Ridge National Labs.  All rights reserved.
! Copyright (c) 2016      Research Organization for Information Science
!                         and Technology (RIST). All rights reserved.
! $COPYRIGHT$
!
! Additional copyrights may follow
!
! $HEADER$
!

        integer MPI_MODE_APPEND
        integer MPI_MODE_CREATE
        integer MPI_MODE_DELETE_ON_CLOSE
        integer MPI_MODE_EXCL
        integer MPI_MODE_RDONLY
        integer MPI_MODE_RDWR
        integer MPI_MODE_SEQUENTIAL
        integer MPI_MODE_UNIQUE_OPEN
        integer MPI_MODE_WRONLY
        integer MPI_SEEK_CUR
        integer MPI_SEEK_END
        integer MPI_SEEK_SET
        integer(KIND=MPI_OFFSET_KIND) MPI_DISPLACEMENT_CURRENT

        parameter (MPI_MODE_APPEND=128)
        parameter (MPI_MODE_CREATE=1)
        parameter (MPI_MODE_DELETE_ON_CLOSE=16)
        parameter (MPI_MODE_EXCL=64)
        parameter (MPI_MODE_RDONLY=2)
        parameter (MPI_MODE_RDWR=8)
        parameter (MPI_MODE_SEQUENTIAL=256)
        parameter (MPI_MODE_UNIQUE_OPEN=32)
        parameter (MPI_MODE_WRONLY=4)
        parameter (MPI_SEEK_CUR=602)
        parameter (MPI_SEEK_END=604)
        parameter (MPI_SEEK_SET=600)
        parameter (MPI_DISPLACEMENT_CURRENT=-54278278)
